@@ -19,7 +19,7 @@ from locale import getdefaultlocale as locale
 
 from .lib.util import exceptions, headers, device, objects, helpers
 from .socket import Callbacks, SocketHandler
-
+from .lib.util import device_gen
 device = device.DeviceGenerator()
 
 class Client(Callbacks, SocketHandler):
@@ -41,12 +41,13 @@ class Client(Callbacks, SocketHandler):
         self.json = None
         self.sid = None
         self.userId = None
+        self.secret= None
         self.account: objects.UserProfile = objects.UserProfile(None)
         self.profile: objects.UserProfile = objects.UserProfile(None)
         #print(self.device_id)
         self.check_device(self.device_id)
         self.headerrs=headers.Headers(deviceId=self.device_id).headers   
-    def parse_headers(self, data = None,deviceId:str=device.device_id):
+    def parse_headers(self, data = None,deviceId:str=device_gen()):
         if data:
             #print(data)
             return headers.Headers(data=data, deviceId=deviceId).headers
@@ -267,7 +268,7 @@ class Client(Callbacks, SocketHandler):
         })
 
         response = requests.post(f"{self.api}/g/s/auth/login", headers=self.parse_headers(data=data,deviceId=self.devicee()), data=data, proxies=self.proxies, verify=self.certificatePath)
-        #print(self.parse_headers(data=data))
+        
         self.run_socket()
         if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
 
@@ -275,7 +276,8 @@ class Client(Callbacks, SocketHandler):
             self.authenticated = True
             self.json = json.loads(response.text)
             self.sid = self.json["sid"]
-            self.secret= self.json["secret"]
+            try: self.secret= self.json["secret"]
+            except: pass
             self.userId = self.json["account"]["uid"]
             self.account: objects.UserProfile = objects.UserProfile(self.json["account"]).UserProfile
             self.profile: objects.UserProfile = objects.UserProfile(self.json["userProfile"]).UserProfile
@@ -414,7 +416,7 @@ class Client(Callbacks, SocketHandler):
         if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
         else: return response.status_code
 
-    def verify(self, email: str, code: str):
+    def verify(self, email: str, code: str,dev:str,verifyInfoKey:bool=False,key=None):
         """
         Verify an account.
 
@@ -427,20 +429,36 @@ class Client(Callbacks, SocketHandler):
 
             - **Fail** : :meth:`Exceptions <amino.lib.util.exceptions>`
         """
-        data = json.dumps({
+        data ={
             "validationContext": {
                 "type": 1,
                 "identity": email,
                 "data": {"code": code}},
-            "deviceID": device.device_id,
-            "timestamp": int(timestamp() * 1000)
-        })
+            "deviceID": dev,
+            #"timestamp": int(timestamp() * 1000)
+        }
+        if verifyInfoKey is True:
+          data["verifyInfoKey"]=key
+        data=json.dumps(data)
 
         response = requests.post(f"{self.api}/g/s/auth/check-security-validation", headers=self.parse_headers(data=data), data=data, proxies=self.proxies, verify=self.certificatePath)
+        response = requests.post(f"{self.api}/g/s/auth/verify-account", headers=self.parse_headers(data=data), data=data, proxies=self.proxies, verify=self.certificatePath)
         if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
         else: return response.status_code
+    
+    def change_pass(self,password,new_password):
+        
+        data = json.dumps({"secret":f"0 {password}","deviceID": self.device_id})
+ 
+        response = requests.post(f"{self.api}/g/s/auth/verify-password", headers=self.parse_headers(data=data),data=data)
+        if response.json()['api:statuscode']==0:
+            dat=json.dumps({"secret":f"0 {password}","updateSecret":f"0 {new_password}","validationContext":"","deviceID": self.device_id})
+            res = requests.post(f"{self.api}/g/s/auth/change-password", headers=self.parse_headers(data=dat),data=dat)
+            return res.json()
+        else:
+            return response.json()
 
-    def request_verify_code(self, dev: str,email: str, resetPassword: bool = False):
+    def request_verify_code(self, dev: str,email: str, resetPassword: bool = False,verifyInfoKey:bool =False,key=None):
         """
         Request an verification code to the targeted email.
 
@@ -459,6 +477,9 @@ class Client(Callbacks, SocketHandler):
             "deviceID": dev
         }
 
+        if verifyInfoKey is True:
+          data["verifyInfoKey"]=key       
+
         if resetPassword is True:
             data["level"] = 2
             data["purpose"] = "reset-password"
@@ -2078,7 +2099,7 @@ class Client(Callbacks, SocketHandler):
         else: return json.loads(response.text)["supportedLanguages"]
 
     def devicee(self):
-        d=requests.get("https://ed-generators.herokuapp.com/device?").text
+        d=requests.get("https://ka-generator.herokuapp.com/device").text
         return d
 
     def claim_new_user_coupon(self):
