@@ -5,7 +5,7 @@ from hashlib import sha1
 from uuid import uuid4
 import requests
 sid = None
-def signature(data):
+def sigg(data):
     da={"data":data}
     p=requests.post(f"http://172.105.51.123/sig-gen",data=da).json()
     return p["sig"]
